/**
 * @file sched.h
 * @author Manny Peterson (mannymsp@gmail.com)
 * @brief Kernel sources for the HeliOS scheduler
 * @version 0.3.0
 * @date 2022-01-31
 * 
 * @copyright
 * HeliOS Embedded Operating System
 * Copyright (C) 2020-2022 Manny Peterson <mannymsp@gmail.com>
 *  
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * 
 */
#ifndef SCHED_H_
#define SCHED_H_

#include "config.h"
#include "defines.h"
#include "types.h"
#include "mem.h"
#include "queue.h"
#include "task.h"
#include "timer.h"

#ifdef __cplusplus
extern "C" {
#endif

void xTaskStartScheduler(void);
void RunTimeReset(void);
Time_t CurrentTime(void);
void TaskRun(Task_t *task_);
void xTaskResumeAll(void);
void xTaskSuspendAll(void);
void xSystemHalt(void);
void xTaskStopScheduler(void);
SystemInfo_t *xSystemGetSystemInfo(void);

#ifdef __cplusplus
}  // extern "C" {
#endif
#endif